import { ChangeDetectionStrategy, Component, ElementRef, EventEmitter, Input, Output, ViewChild, ViewEncapsulation, } from '@angular/core';
// Unique ID for each instance
let nextUniqueId = 0;
export const tsButtonActionTypes = [
    'Button',
    'Submit',
    'Menu',
    'Reset',
];
export const tsButtonFunctionTypes = [
    'button',
    'search',
    'submit',
];
/**
 * The list of supported theme names
 */
export const tsButtonThemes = [
    'default',
    'secondary',
    'warning',
    'alternate-primary',
];
/**
 * A presentational component to render a button
 *
 * @example
 * <ts-button
 *              actionName="Submit"
 *              buttonType="search"
 *              [isDisabled]="false"
 *              [isSmall]="true"
 *              [showProgress]="true"
 *              tabIndex="2"
 *              textContent="Click Me!"
 *              theme="warning"
 *              (clicked)="myMethod($event)"
 * >Click Me!</ts-button>
 *
 * <example-url>https://release--5f0ca4e61af3790022cad2fe.chromatic.com/?path=/story/components-actions-button</example-url>
 */
export class TsButtonComponent {
    constructor(elementRef) {
        this.elementRef = elementRef;
        /**
         * A flag to determine if click events should be intercepted.
         *
         * Set by {@link TsConfirmationDirective}
         */
        this.interceptClick = false;
        /**
         * Define the default component ID
         */
        this.uid = `ts-button-${nextUniqueId++}`;
        /**
         * Define the action for the aria-label. {@link TsButtonActionTypes}
         */
        this.actionName = 'Button';
        /**
         * Define the button type. {@link TsButtonFunctionTypes}
         */
        this.buttonType = 'button';
        /**
         * Define if the button is disabled
         */
        this.isDisabled = false;
        /**
         * Define if the button is the smaller format
         */
        this.isSmall = false;
        this._id = this.uid;
        /**
         * Define the checkbox text content.
         *
         * NOTE: This will not display if any content is passed in through <ng-content>
         */
        this.textContent = '';
        /**
         * Define if the progress indicator should show
         */
        this.showProgress = false;
        /**
         * Define the tabindex for the button
         */
        this.tabIndex = 0;
        this._theme = 'default';
        /**
         * Pass the click event through to the parent
         */
        this.clicked = new EventEmitter();
    }
    /**
     * Getter returning a boolean based on both the component `isDisabled` flag and the FormControl's disabled status
     */
    get shouldBeDisabled() {
        return this.isDisabled || this.showProgress;
    }
    /**
     * Define an ID for the component
     *
     * @param value
     */
    set id(value) {
        this._id = value || this.uid;
    }
    get id() {
        return this._id;
    }
    /**
     * Define the theme
     *
     * @param value - The theme name
     */
    set theme(value) {
        this._theme = value ? value : 'default';
    }
    get theme() {
        return this._theme;
    }
    /**
     * Handle button clicks
     *
     * @internal
     *
     * @param event - The MouseEvent
     */
    clickedButton(event) {
        if (this.interceptClick) {
            // Save the original event but don't emit the originalClickEvent
            this.originalClickEvent = event;
        }
        else {
            // Allow the click to propagate
            this.clicked.emit(event);
        }
    }
}
TsButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'ts-button',
                template: "<button\n  class=\"c-button c-button--{{ theme }}\"\n  [ngClass]=\"{\n    'c-button--progress': showProgress && !isDisabled,\n    'c-button--small': isSmall\n  }\"\n  [attr.aria-label]=\"actionName\"\n  [attr.id]=\"id\"\n  [attr.type]=\"buttonType\"\n  [disabled]=\"shouldBeDisabled\"\n  tabindex=\"{{ tabIndex }}\"\n  (click)=\"clickedButton($event)\"\n  #button\n>\n  <span class=\"c-button__content\">\n    <span class=\"c-button__content-ng-content\"><ng-content></ng-content></span>\n    <span class=\"c-button__content-input\">{{ textContent }}</span>\n  </span>\n\n  <span\n    class=\"c-button__spinner\"\n    *ngIf=\"showProgress && !isDisabled\"\n    [ngClass]=\"{'c-button__spinner--active': showProgress && !isDisabled}\"\n  >\n    <svg width=\"100%\" height=\"100%\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\">\n      <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle>\n    </svg>\n  </span>\n</button>\n",
                host: { class: 'ts-button' },
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                exportAs: 'tsButton',
                styles: [":root{--tsb-animationEasing:var(--ts-animation-easing-ease);--tsb-backgroundColor:var(--ts-color-primary-500);--tsb-borderColor:var(--ts-color-primary-500);--tsb-borderRadius:var(--ts-border-radius-base);--tsb-borderRadius-collapsible:2em;--tsb-boxShadow-color:var(--ts-color-primary-300);--tsb-button-transitionDuration:var(--ts-animation-time-duration-200);--tsb-collapsible-first-icon-adjustment:-.15em;--tsb-color:var(--ts-color-light);--tsb-color-disabled:var(--ts-color-utility-600);--tsb-content-maxWidth:400px;--tsb-content-transitionDuration:var(--ts-animation-time-duration-400);--tsb-fontSize:14px;--tsb-icon-horizontal-adjustment:.2em;--tsb-icon-negative-padding-adjustment:-4px;--tsb-icon-padding:0 .2em;--tsb-icon-vertical-adjustment:-.15em;--tsb-lineHeight:35px;--tsb-margin:4px 0;--tsb-padding:0 var(--tsb-padding-base);--tsb-padding-base:var(--ts-space-inset-400);--tsb-padding-collapsed:0 6px;--tsb-padding-right-progress:44px;--tsb-rotation:180deg;--tsb-shadow-focus:0 0 2px 2px var(--tsb-boxShadow-color);--tsb-spinner-color:var(--ts-color-utility-500);--tsb-spinner-transition:opacity calc(var(--tsb-content-transitionDuration) - 200ms) var(--tsb-animationEasing);--tsb-spinner-xy:21px;--tsb-theme-alternate-primary-backgroundColor:#2d8734;--tsb-theme-alternate-primary-backgroundColor-active:#194a1c;--tsb-theme-alternate-primary-backgroundColor-disabled:var(--ts-color-utility-300);--tsb-theme-alternate-primary-backgroundColor-focus:#2d8734;--tsb-theme-alternate-primary-backgroundColor-hover:#236828;--tsb-theme-alternate-primary-borderColor:#2d8734;--tsb-theme-alternate-primary-borderColor-active:#194a1c;--tsb-theme-alternate-primary-borderColor-disabled:var(--ts-color-utility-300);--tsb-theme-alternate-primary-borderColor-focus:#2d8734;--tsb-theme-alternate-primary-borderColor-hover:#236828;--tsb-theme-alternate-primary-boxShadow-color-focus:#37a640;--tsb-theme-alternate-primary-color:var(--ts-color-light);--tsb-theme-alternate-primary-color-active:var(--ts-color-light);--tsb-theme-alternate-primary-color-focus:var(--ts-color-light);--tsb-theme-default-backgroundColor:var(--ts-color-primary-500);--tsb-theme-default-backgroundColor-active:var(--ts-color-primary-900);--tsb-theme-default-backgroundColor-disabled:var(--ts-color-utility-300);--tsb-theme-default-backgroundColor-focus:var(--ts-color-primary-500);--tsb-theme-default-backgroundColor-hover:var(--ts-color-primary-700);--tsb-theme-default-borderColor:var(--ts-color-primary-500);--tsb-theme-default-borderColor-active:var(--ts-color-primary-900);--tsb-theme-default-borderColor-disabled:var(--ts-color-utility-300);--tsb-theme-default-borderColor-focus:var(--ts-color-primary-500);--tsb-theme-default-borderColor-hover:var(--ts-color-primary-700);--tsb-theme-default-boxShadow-color-focus:var(--ts-color-primary-300);--tsb-theme-default-color:var(--ts-color-light);--tsb-theme-default-color-active:var(--ts-color-light);--tsb-theme-default-color-focus:var(--ts-color-light);--tsb-theme-secondary-backgroundColor:var(--ts-color-light);--tsb-theme-secondary-backgroundColor-active:var(--ts-color-primary-300);--tsb-theme-secondary-backgroundColor-disabled:var(--ts-color-light);--tsb-theme-secondary-backgroundColor-focus:var(--ts-color-light);--tsb-theme-secondary-backgroundColor-hover:var(--ts-color-primary-100);--tsb-theme-secondary-borderColor:var(--ts-color-utility-300);--tsb-theme-secondary-borderColor-active:var(--ts-color-utility-600);--tsb-theme-secondary-borderColor-disabled:var(--ts-color-utility-200);--tsb-theme-secondary-borderColor-focus:var(--ts-color-utility-400);--tsb-theme-secondary-borderColor-hover:var(--ts-color-utility-500);--tsb-theme-secondary-boxShadow-color-focus:var(--ts-color-primary-300);--tsb-theme-secondary-color:var(--ts-color-primary-500);--tsb-theme-secondary-color-active:var(--ts-color-primary-500);--tsb-theme-secondary-color-focus:var(--ts-color-primary-500);--tsb-theme-warning-backgroundColor:var(--ts-color-light);--tsb-theme-warning-backgroundColor-active:var(--ts-color-warn-300);--tsb-theme-warning-backgroundColor-disabled:var(--ts-color-light);--tsb-theme-warning-backgroundColor-focus:var(--ts-color-light);--tsb-theme-warning-backgroundColor-hover:var(--ts-color-warn-100);--tsb-theme-warning-borderColor:var(--ts-color-utility-300);--tsb-theme-warning-borderColor-active:var(--ts-color-utility-600);--tsb-theme-warning-borderColor-disabled:var(--ts-color-utility-200);--tsb-theme-warning-borderColor-focus:var(--ts-color-utility-400);--tsb-theme-warning-borderColor-hover:var(--ts-color-utility-500);--tsb-theme-warning-boxShadow-color-focus:var(--ts-color-warn-300);--tsb-theme-warning-color:var(--ts-color-warn-500);--tsb-theme-warning-color-active:var(--ts-color-warn-500);--tsb-theme-warning-color-focus:var(--ts-color-warn-500);--tsb-typography:var(--ts-typography-compound-body2)}@-webkit-keyframes rotation{0%{transform:rotate(0deg)}to{transform:rotate(270deg)}}@keyframes rotation{0%{transform:rotate(0deg)}to{transform:rotate(270deg)}}@-webkit-keyframes dash{0%{stroke-dashoffset:187}50%{stroke-dashoffset:46.75;transform:rotate(135deg)}to{stroke-dashoffset:187;transform:rotate(450deg)}}@keyframes dash{0%{stroke-dashoffset:187}50%{stroke-dashoffset:46.75;transform:rotate(135deg)}to{stroke-dashoffset:187;transform:rotate(450deg)}}.ts-button{display:inline-block;margin:var(--tsb-margin)}.ts-button .c-button{background-color:var(--tsb-backgroundColor);border:1px solid var(--tsb-borderColor);border-radius:var(--tsb-borderRadius);color:var(--tsb-color);cursor:pointer;font:var(--tsb-typography);font-size:var(--tsb-fontSize);line-height:var(--tsb-lineHeight);padding:var(--tsb-padding);position:relative;transition-duration:var(--tsb-button-transitionDuration);transition-property:color,box-shadow,border-color,background-color;transition-timing-function:var(--tsb-animationEasing)}.ts-button .c-button[disabled]{--tsb-borderColor:var(--tsb-theme-default-borderColor-disabled);--tsb-color:var(--tsb-color-disabled);cursor:not-allowed}.ts-button .c-button:focus{box-shadow:var(--tsb-shadow-focus);outline:none}.ts-button .c-button--default{--tsb-backgroundColor:var(--tsb-theme-default-backgroundColor);--tsb-borderColor:var(--tsb-theme-default-borderColor);--tsb-boxShadow-color:var(--tsb-theme-default-boxShadow-color-focus);--tsb-color:var(--tsb-theme-default-color)}.ts-button .c-button--default[disabled]{--tsb-backgroundColor:var(--tsb-theme-default-backgroundColor-disabled);--tsb-borderColor:var(--tsb-theme-default-borderColor-disabled)}.ts-button .c-button--default:not([disabled]):hover{--tsb-backgroundColor:var(--tsb-theme-default-backgroundColor-hover);--tsb-borderColor:var(--tsb-theme-default-borderColor-hover)}.ts-button .c-button--default:not([disabled]):focus{--tsb-borderColor:var(--tsb-theme-default-borderColor-focus)!important;--tsb-boxShadow-color:var(--tsb-theme-default-boxShadow-color-focus)}.ts-button .c-button--default:not([disabled]):focus:hover{--tsb-borderColor:var(--tsb-theme-default-backgroundColor-hover)}.ts-button .c-button--default:not([disabled]):active{--tsb-backgroundColor:var(--tsb-theme-default-backgroundColor-active);--tsb-borderColor:var(--tsb-theme-default-borderColor-active)}.ts-button .c-button--secondary{--tsb-backgroundColor:var(--tsb-theme-secondary-backgroundColor);--tsb-borderColor:var(--tsb-theme-secondary-borderColor);--tsb-boxShadow-color:var(--tsb-theme-secondary-boxShadow-color-focus);--tsb-color:var(--tsb-theme-secondary-color)}.ts-button .c-button--secondary[disabled]{--tsb-backgroundColor:var(--tsb-theme-secondary-backgroundColor-disabled);--tsb-borderColor:var(--tsb-theme-secondary-borderColor-disabled)}.ts-button .c-button--secondary:not([disabled]):hover{--tsb-backgroundColor:var(--tsb-theme-secondary-backgroundColor-hover);--tsb-borderColor:var(--tsb-theme-secondary-borderColor-hover)}.ts-button .c-button--secondary:not([disabled]):focus{--tsb-borderColor:var(--tsb-theme-secondary-borderColor-focus)!important;--tsb-boxShadow-color:var(--tsb-theme-secondary-boxShadow-color-focus)}.ts-button .c-button--secondary:not([disabled]):focus:hover{--tsb-borderColor:var(--tsb-theme-secondary-backgroundColor-hover)}.ts-button .c-button--secondary:not([disabled]):active{--tsb-backgroundColor:var(--tsb-theme-secondary-backgroundColor-active);--tsb-borderColor:var(--tsb-theme-secondary-borderColor-active)}.ts-button .c-button--warning{--tsb-backgroundColor:var(--tsb-theme-warning-backgroundColor);--tsb-borderColor:var(--tsb-theme-warning-borderColor);--tsb-boxShadow-color:var(--tsb-theme-warning-boxShadow-color-focus);--tsb-color:var(--tsb-theme-warning-color)}.ts-button .c-button--warning[disabled]{--tsb-backgroundColor:var(--tsb-theme-warning-backgroundColor-disabled);--tsb-borderColor:var(--tsb-theme-warning-borderColor-disabled)}.ts-button .c-button--warning:not([disabled]):hover{--tsb-backgroundColor:var(--tsb-theme-warning-backgroundColor-hover);--tsb-borderColor:var(--tsb-theme-warning-borderColor-hover)}.ts-button .c-button--warning:not([disabled]):focus{--tsb-borderColor:var(--tsb-theme-warning-borderColor-focus)!important;--tsb-boxShadow-color:var(--tsb-theme-warning-boxShadow-color-focus)}.ts-button .c-button--warning:not([disabled]):focus:hover{--tsb-borderColor:var(--tsb-theme-warning-backgroundColor-hover)}.ts-button .c-button--warning:not([disabled]):active{--tsb-backgroundColor:var(--tsb-theme-warning-backgroundColor-active);--tsb-borderColor:var(--tsb-theme-warning-borderColor-active)}.ts-button .c-button--alternate-primary{--tsb-backgroundColor:var(--tsb-theme-alternate-primary-backgroundColor);--tsb-borderColor:var(--tsb-theme-alternate-primary-borderColor);--tsb-boxShadow-color:var(--tsb-theme-alternate-primary-boxShadow-color-focus);--tsb-color:var(--tsb-theme-alternate-primary-color)}.ts-button .c-button--alternate-primary[disabled]{--tsb-backgroundColor:var(--tsb-theme-alternate-primary-backgroundColor-disabled);--tsb-borderColor:var(--tsb-theme-alternate-primary-borderColor-disabled)}.ts-button .c-button--alternate-primary:not([disabled]):hover{--tsb-backgroundColor:var(--tsb-theme-alternate-primary-backgroundColor-hover);--tsb-borderColor:var(--tsb-theme-alternate-primary-borderColor-hover)}.ts-button .c-button--alternate-primary:not([disabled]):focus{--tsb-borderColor:var(--tsb-theme-alternate-primary-borderColor-focus)!important;--tsb-boxShadow-color:var(--tsb-theme-alternate-primary-boxShadow-color-focus)}.ts-button .c-button--alternate-primary:not([disabled]):focus:hover{--tsb-borderColor:var(--tsb-theme-alternate-primary-backgroundColor-hover)}.ts-button .c-button--alternate-primary:not([disabled]):active{--tsb-backgroundColor:var(--tsb-theme-alternate-primary-backgroundColor-active);--tsb-borderColor:var(--tsb-theme-alternate-primary-borderColor-active)}.ts-button .c-button__icon{display:inline-block;margin-right:var(--tsb-icon-horizontal-adjustment)}.ts-button .c-button__content .c-button__content-ng-content:not(:empty)+.c-button__content-input{display:none}.ts-button .c-button .c-button__spinner{display:block;height:var(--tsb-spinner-xy);opacity:0;position:absolute;right:var(--tsb-padding-base);top:50%;transform:translateY(calc(-50% - 2px));transition:var(--tsb-spinner-transition);width:var(--tsb-spinner-xy)}.ts-button .c-button .c-button__spinner--active{opacity:1}.ts-button .c-button .c-button__spinner svg{-webkit-animation:rotation 1.4s linear infinite;animation:rotation 1.4s linear infinite;transform-origin:center}.ts-button .c-button .c-button__spinner circle{-webkit-animation:dash 1.4s ease-in-out infinite;animation:dash 1.4s ease-in-out infinite;stroke:var(--tsb-spinner-color);stroke-dasharray:187;stroke-dashoffset:0;transform-origin:center}.ts-button .c-button--progress{padding-right:var(--tsb-padding-right-progress)}.ts-button .c-button--small{font-size:13px;line-height:14px;padding:4px 8px}.ts-button .c-button--small .fa,.ts-button .c-button--small .fas{transform:scale(.84)}"]
            },] }
];
TsButtonComponent.ctorParameters = () => [
    { type: ElementRef }
];
TsButtonComponent.propDecorators = {
    button: [{ type: ViewChild, args: ['button', { static: true },] }],
    actionName: [{ type: Input }],
    buttonType: [{ type: Input }],
    isDisabled: [{ type: Input }],
    isSmall: [{ type: Input }],
    id: [{ type: Input }],
    textContent: [{ type: Input }],
    showProgress: [{ type: Input }],
    tabIndex: [{ type: Input }],
    theme: [{ type: Input }],
    clicked: [{ type: Output }]
};
//# sourceMappingURL=button.component.js.map