import { ElementRef, EventEmitter } from '@angular/core';
/**
 * Define the allowed {@link TsButtonComponent} action types
 */
export declare type TsButtonActionTypes = 'Button' | 'Submit' | 'Menu' | 'Reset';
export declare const tsButtonActionTypes: string[];
/**
 * Define the allowed {@link TsButtonComponent} action types
 */
export declare type TsButtonFunctionTypes = 'button' | 'search' | 'submit';
export declare const tsButtonFunctionTypes: string[];
/**
 * Supported themes for buttons
 */
export declare type TsButtonThemeTypes = 'default' | 'secondary' | 'warning' | 'alternate-primary';
/**
 * The list of supported theme names
 */
export declare const tsButtonThemes: ReadonlyArray<TsButtonThemeTypes>;
/**
 * A presentational component to render a button
 *
 * @example
 * <ts-button
 *              actionName="Submit"
 *              buttonType="search"
 *              [isDisabled]="false"
 *              [isSmall]="true"
 *              [showProgress]="true"
 *              tabIndex="2"
 *              textContent="Click Me!"
 *              theme="warning"
 *              (clicked)="myMethod($event)"
 * >Click Me!</ts-button>
 *
 * <example-url>https://release--5f0ca4e61af3790022cad2fe.chromatic.com/?path=/story/components-actions-button</example-url>
 */
export declare class TsButtonComponent {
    elementRef: ElementRef;
    /**
     * A flag to determine if click events should be intercepted.
     *
     * Set by {@link TsConfirmationDirective}
     */
    interceptClick: boolean;
    /**
     * Store the original event from a click (used when `interceptClick` is true)
     *
     * @internal
     *
     * Used by {@link TsConfirmationDirective}
     */
    originalClickEvent: MouseEvent;
    /**
     * Define the default component ID
     */
    readonly uid: string;
    /**
     * Getter returning a boolean based on both the component `isDisabled` flag and the FormControl's disabled status
     */
    get shouldBeDisabled(): boolean;
    /**
     * Provide access to the inner button element
     */
    button: ElementRef;
    /**
     * Define the action for the aria-label. {@link TsButtonActionTypes}
     */
    actionName: TsButtonActionTypes;
    /**
     * Define the button type. {@link TsButtonFunctionTypes}
     */
    buttonType: TsButtonFunctionTypes;
    /**
     * Define if the button is disabled
     */
    isDisabled: boolean;
    /**
     * Define if the button is the smaller format
     */
    isSmall: boolean;
    /**
     * Define an ID for the component
     *
     * @param value
     */
    set id(value: string);
    get id(): string;
    protected _id: string;
    /**
     * Define the checkbox text content.
     *
     * NOTE: This will not display if any content is passed in through <ng-content>
     */
    textContent: string;
    /**
     * Define if the progress indicator should show
     */
    showProgress: boolean;
    /**
     * Define the tabindex for the button
     */
    tabIndex: number;
    /**
     * Define the theme
     *
     * @param value - The theme name
     */
    set theme(value: TsButtonThemeTypes);
    get theme(): TsButtonThemeTypes;
    private _theme;
    /**
     * Pass the click event through to the parent
     */
    readonly clicked: EventEmitter<MouseEvent>;
    constructor(elementRef: ElementRef);
    /**
     * Handle button clicks
     *
     * @internal
     *
     * @param event - The MouseEvent
     */
    clickedButton(event: MouseEvent): void;
}
